@@ -1,3 +1,5 @@
+use std::{borrow::Borrow, result};
+
 use super::conversion_type::ConversionType;
 use crate::{
     analysis::{record_type::RecordType, ref_mode::RefMode, try_from_glib::TryFromGlib},
@@ -8,8 +10,6 @@ use crate::{
     traits::*,
 };
 
-use std::{borrow::Borrow, result};
-
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum TypeError {
     Ignored(String),
@@ -30,7 +30,8 @@ impl RustType {
         RustTypeBuilder::new(env, type_id).try_build()
     }
 
-    /// Create a `RustTypeBuilder` which allows specifying additional configuration.
+    /// Create a `RustTypeBuilder` which allows specifying additional
+    /// configuration.
     pub fn builder(env: &Env, type_id: library::TypeId) -> RustTypeBuilder<'_> {
         RustTypeBuilder::new(env, type_id)
     }
@@ -116,7 +117,7 @@ impl RustType {
     #[inline]
     fn format_parameter(self, direction: ParameterDirection) -> Self {
         if direction.is_out() {
-            self.alter_type(|type_| format!("&mut {}", type_))
+            self.alter_type(|type_| format!("&mut {type_}"))
         } else {
             self
         }
@@ -126,7 +127,7 @@ impl RustType {
     fn apply_ref_mode(self, ref_mode: RefMode) -> Self {
         match ref_mode.for_rust_type() {
             "" => self,
-            ref_mode => self.alter_type(|typ_| format!("{}{}", ref_mode, typ_)),
+            ref_mode => self.alter_type(|typ_| format!("{ref_mode}{typ_}")),
         }
     }
 }
@@ -161,9 +162,9 @@ impl IntoString for Result {
         use self::TypeError::*;
         match self {
             Ok(s) => s.into_string(),
-            Err(Ignored(s)) => format!("/*Ignored*/{}", s),
-            Err(Mismatch(s)) => format!("/*Metadata mismatch*/{}", s),
-            Err(Unimplemented(s)) => format!("/*Unimplemented*/{}", s),
+            Err(Ignored(s)) => format!("/*Ignored*/{s}"),
+            Err(Mismatch(s)) => format!("/*Metadata mismatch*/{s}"),
+            Err(Unimplemented(s)) => format!("/*Unimplemented*/{s}"),
         }
     }
 }
@@ -194,7 +195,7 @@ pub struct RustTypeBuilder<'env> {
 
 impl<'env> RustTypeBuilder<'env> {
     fn new(env: &'env Env, type_id: library::TypeId) -> Self {
-        RustTypeBuilder {
+        Self {
             env,
             type_id,
             direction: ParameterDirection::None,
@@ -266,16 +267,16 @@ impl<'env> RustTypeBuilder<'env> {
                     Int64 => ok("i64"),
                     UInt64 => ok("u64"),
 
-                    Int => ok("i32"),  //maybe dependent on target system
-                    UInt => ok("u32"), //maybe dependent on target system
+                    Int => ok("i32"),  // maybe dependent on target system
+                    UInt => ok("u32"), // maybe dependent on target system
 
-                    Short => ok_and_use("libc::c_short"), //depends of target system
-                    UShort => ok_and_use("libc::c_ushort"), //depends o f target system
-                    Long => ok_and_use("libc::c_long"),   //depends of target system
-                    ULong => ok_and_use("libc::c_ulong"), //depends of target system
+                    Short => ok_and_use("libc::c_short"), // depends of target system
+                    UShort => ok_and_use("libc::c_ushort"), // depends o f target system
+                    Long => ok_and_use("libc::c_long"),   // depends of target system
+                    ULong => ok_and_use("libc::c_ulong"), // depends of target system
 
-                    Size => ok("usize"),  //depends of target system
-                    SSize => ok("isize"), //depends of target system
+                    Size => ok("usize"),  // depends of target system
+                    SSize => ok("isize"), // depends of target system
 
                     Float => ok("f32"),
                     Double => ok("f64"),
@@ -306,7 +307,7 @@ impl<'env> RustTypeBuilder<'env> {
                     Char => ok_and_use(&use_glib_type(self.env, "Char")),
                     UChar => ok_and_use(&use_glib_type(self.env, "UChar")),
                     Unsupported => err("Unsupported"),
-                    _ => err(&format!("Basic: {:?}", fund)),
+                    _ => err(&format!("Basic: {fund:?}")),
                 }
             }
             Alias(ref alias) => {
@@ -370,9 +371,9 @@ impl<'env> RustTypeBuilder<'env> {
                     .map_any(|rust_type| {
                         rust_type.alter_type(|typ| {
                             if self.ref_mode.is_ref() {
-                                format!("[{}]", typ)
+                                format!("[{typ}]")
                             } else {
-                                format!("Vec<{}>", typ)
+                                format!("Vec<{typ}>")
                             }
                         })
                     })
@@ -391,8 +392,8 @@ impl<'env> RustTypeBuilder<'env> {
                         Int64 => Some("i64"),
                         UInt64 => Some("u64"),
 
-                        Int => Some("i32"),  //maybe dependent on target system
-                        UInt => Some("u32"), //maybe dependent on target system
+                        Int => Some("i32"),  // maybe dependent on target system
+                        UInt => Some("u32"), // maybe dependent on target system
 
                         Float => Some("f32"),
                         Double => Some("f64"),
@@ -402,9 +403,9 @@ impl<'env> RustTypeBuilder<'env> {
                     if let Some(s) = array_type {
                         skip_option = true;
                         if self.ref_mode.is_ref() {
-                            Ok(format!("[{}]", s).into())
+                            Ok(format!("[{s}]").into())
                         } else {
-                            Ok(format!("Vec<{}>", s).into())
+                            Ok(format!("Vec<{s}>").into())
                         }
                     } else {
                         Err(TypeError::Unimplemented(type_.get_name()))
@@ -436,7 +437,7 @@ impl<'env> RustTypeBuilder<'env> {
                     )
                     .into());
                 } else if full_name == "GLib.DestroyNotify" {
-                    return Ok(format!("Fn(){} + 'static", concurrency).into());
+                    return Ok(format!("Fn(){concurrency} + 'static").into());
                 }
                 let mut params = Vec::with_capacity(f.parameters.len());
                 let mut err = false;
@@ -530,9 +531,9 @@ impl<'env> RustTypeBuilder<'env> {
                 }
                 Ok(if *self.nullable {
                     if self.scope.is_call() {
-                        format!("Option<&mut dyn ({})>", ret)
+                        format!("Option<&mut dyn ({ret})>")
                     } else {
-                        format!("Option<Box_<dyn {} + 'static>>", ret)
+                        format!("Option<Box_<dyn {ret} + 'static>>")
                     }
                 } else {
                     format!(
@@ -559,9 +560,9 @@ impl<'env> RustTypeBuilder<'env> {
                 rust_type = rust_type.map_any(|rust_type| {
                     rust_type
                         .alter_type(|typ_| {
-                            let mut opt = format!("Option<{}>", typ_);
+                            let mut opt = format!("Option<{typ_}>");
                             if self.direction == ParameterDirection::In {
-                                opt = format!("impl Into<{}>", opt);
+                                opt = format!("impl Into<{opt}>");
                             }
 
                             opt
@@ -599,7 +600,7 @@ impl<'env> RustTypeBuilder<'env> {
             match ConversionType::of(self.env, self.type_id) {
                 ConversionType::Pointer | ConversionType::Scalar => {
                     rust_type = rust_type.map_any(|rust_type| {
-                        rust_type.alter_type(|typ_| format!("Option<{}>", typ_))
+                        rust_type.alter_type(|typ_| format!("Option<{typ_}>"))
                     });
                 }
                 _ => (),
@@ -615,8 +616,7 @@ impl<'env> RustTypeBuilder<'env> {
 
         assert!(
             self.direction != ParameterDirection::None,
-            "undefined direction for parameter with type {:?}",
-            type_
+            "undefined direction for parameter with type {type_:?}"
         );
 
         let rust_type = RustType::builder(self.env, self.type_id)
