@@ -6,7 +6,7 @@ use std::{
 
 use super::{function, trait_impls};
 use crate::{
-    analysis::{enums::Info, special_functions::Type},
+    analysis::enums::Info,
     codegen::{
         general::{
             self, allow_deprecated, cfg_condition, cfg_condition_no_doc, cfg_condition_string,
@@ -226,35 +226,6 @@ fn generate_enum(
 
     writeln!(w)?;
 
-    if config.generate_display_trait && !analysis.specials.has_trait(Type::Display) {
-        // Generate Display trait implementation.
-        version_condition(w, env, None, enum_.version, false, 0)?;
-        cfg_condition_no_doc(w, config.cfg_condition.as_ref(), false, 0)?;
-        allow_deprecated(w, any_deprecated_version, false, 0)?;
-        writeln!(
-            w,
-            "impl fmt::Display for {0} {{\n\
-             \tfn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {{\n\
-             \t\twrite!(f, \"{0}::{{}}\", match *self {{",
-            enum_.name
-        )?;
-        for member in &members {
-            version_condition_no_doc(w, env, None, member.version, false, 3)?;
-            cfg_condition_no_doc(w, member.cfg_condition.as_ref(), false, 3)?;
-            writeln!(w, "\t\t\tSelf::{0} => \"{0}\",", member.name)?;
-        }
-
-        if !config.exhaustive {
-            writeln!(
-                w,
-                "\t\t\t_ => \"Unknown\",\n\
-                 \t\t}})\n\
-                 \t}}\n\
-                 }}\n"
-            )?;
-        }
-    }
-
     // Only inline from_glib / into_glib implementations if there are not many enums members
     let maybe_inline = if members.len() <= 12 || config.exhaustive {
         "#[inline]\n"
@@ -393,10 +364,11 @@ impl FromGlib<{sys_crate_name}::{ffi_name}> for {name} {{
             ErrorDomain::Quark(quark) => {
                 writeln!(
                     w,
-                    "        static QUARK: once_cell::sync::Lazy<{0}ffi::GQuark> = once_cell::sync::Lazy::new(|| unsafe {{
+                    "        static QUARK: ::std::sync::OnceLock<{0}ffi::GQuark> = ::std::sync::OnceLock::new();
+        let quark = *QUARK.get_or_init(|| unsafe {{
             {0}ffi::g_quark_from_static_string(b\"{1}\\0\".as_ptr() as *const _)
         }});
-        unsafe {{ from_glib(*QUARK) }}",
+        unsafe {{ from_glib(quark) }}",
                     use_glib_if_needed(env, ""),
                     quark,
                 )?;
