@@ -41,6 +41,7 @@ fn generate_lib(w: &mut dyn Write, env: &Env) -> Result<()> {
     general::start_comments(w, &env.config)?;
     statics::begin(w)?;
 
+    generate_extern_crates(w, env)?;
     include_custom_modules(w, env)?;
     statics::after_extern_crates(w)?;
 
@@ -104,6 +105,21 @@ fn generate_lib(w: &mut dyn Write, env: &Env) -> Result<()> {
     Ok(())
 }
 
+fn generate_extern_crates(w: &mut dyn Write, env: &Env) -> Result<()> {
+    for library in &env.config.external_libraries {
+        w.write_all(
+            format!(
+                "use {}_sys as {};\n",
+                library.crate_name.replace('-', "_"),
+                crate_name(&library.namespace)
+            )
+            .as_bytes(),
+        )?;
+    }
+
+    Ok(())
+}
+
 fn include_custom_modules(w: &mut dyn Write, env: &Env) -> Result<()> {
     let modules = find_modules(env)?;
     if !modules.is_empty() {
@@ -124,9 +140,8 @@ fn find_modules(env: &Env) -> Result<Vec<String>> {
     let mut vec = Vec::<String>::new();
     for entry in fs::read_dir(&env.config.auto_path)? {
         let path = entry?.path();
-        let ext = match path.extension() {
-            Some(ext) => ext,
-            None => continue,
+        let Some(ext) = path.extension() else {
+            continue;
         };
         if ext != "rs" {
             continue;
@@ -453,7 +468,7 @@ fn generate_records(w: &mut dyn Write, env: &Env, records: &[&Record]) -> Result
             // 5. Thus, we use custom generated GHookList.
             //    Hopefully someone will profit from all this.
             generate_ghooklist(w)?;
-        } else if record.disguised {
+        } else if record.disguised || record.pointer {
             generate_disguised(w, env, record)?;
         } else {
             let align = config.and_then(|c| c.align);
@@ -500,7 +515,11 @@ fn generate_disguised(w: &mut dyn Write, env: &Env, record: &Record) -> Result<(
     cfg_condition(w, cfg_condition_, false, 0)?;
     generate_opaque_type(w, &format!("_{}", record.c_type))?;
     cfg_condition(w, cfg_condition_, false, 0)?;
-    writeln!(w, "pub type {name} = *mut _{name};", name = record.c_type)?;
+    if record.pointer {
+        writeln!(w, "pub type {name} = *mut _{name};", name = record.c_type)?;
+    } else {
+        writeln!(w, "pub type {name} = _{name};", name = record.c_type)?;
+    }
     writeln!(w)
 }
 
