@@ -82,9 +82,15 @@ pub enum ParameterScope {
     ///
     /// Can be invoked multiple times.
     Notified,
+    /// Forever scope
+    Forever,
 }
 
 impl ParameterScope {
+    pub fn is_forever(self) -> bool {
+        matches!(self, Self::Forever)
+    }
+
     pub fn is_call(self) -> bool {
         matches!(self, Self::Call)
     }
@@ -106,6 +112,7 @@ impl FromStr for ParameterScope {
             "call" => Ok(Self::Call),
             "async" => Ok(Self::Async),
             "notified" => Ok(Self::Notified),
+            "forever" => Ok(Self::Forever),
             _ => Err(format!("Unknown parameter scope type: {name}")),
         }
     }
@@ -427,8 +434,11 @@ pub struct Record {
     pub deprecated_version: Option<Version>,
     pub doc: Option<String>,
     pub doc_deprecated: Option<String>,
-    /// A 'disguised' record is one where the c:type is a typedef that
+    /// A 'pointer' record is one where the c:type is a typedef that
     /// doesn't look like a pointer, but is internally: typedef struct _X *X;
+    pub pointer: bool,
+    /// A 'disguised' record is one where the c:type is a typedef to
+    /// a struct whose content and size are unknown, it is :typedef struct _X X;
     pub disguised: bool,
 }
 
