@@ -26,9 +26,8 @@ impl Library {
         for dir in dirs {
             let dir: &Path = dir.as_ref();
             let file_name = make_file_name(dir, &libs[libs.len() - 1]);
-            let mut parser = match XmlParser::from_path(&file_name) {
-                Ok(p) => p,
-                _ => continue,
+            let Ok(mut parser) = XmlParser::from_path(&file_name) else {
+                continue;
             };
             return parser.document(|p, _| {
                 p.element_with_name("repository", |sub_parser, _elem| {
@@ -306,6 +305,7 @@ impl Library {
         let gtype_struct_for = elem.attr("is-gtype-struct-for");
         let version = self.read_version(parser, ns_id, elem)?;
         let deprecated_version = self.read_deprecated_version(parser, ns_id, elem)?;
+        let pointer = elem.attr_bool("pointer", false);
         let disguised = elem.attr_bool("disguised", false);
 
         let mut fields = Vec::new();
@@ -407,6 +407,7 @@ impl Library {
             doc,
             doc_deprecated,
             disguised,
+            pointer,
             symbol_prefix,
         });
 
